from edc_model.models import BaseUuidModel
from edc_sites.model_mixins import SiteModelMixin
from edc_visit_schedule.model_mixins import OnScheduleModelMixin


class OnSchedule(OnScheduleModelMixin, SiteModelMixin, BaseUuidModel):
    """A model used by the system. Auto-completed by subject_consent."""

    class Meta(OnScheduleModelMixin.Meta, BaseUuidModel.Meta):
        pass


class OnSchedulePregnancy(OnScheduleModelMixin, SiteModelMixin, BaseUuidModel):
    class Meta(OnScheduleModelMixin.Meta, BaseUuidModel.Meta):
        pass


class OnSchedulePostnatal(OnScheduleModelMixin, SiteModelMixin, BaseUuidModel):
    class Meta(OnScheduleModelMixin.Meta):
        pass


class OnScheduleDmReferral(OnScheduleModelMixin, SiteModelMixin, BaseUuidModel):
    class Meta(OnScheduleModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "On-schedule: DM Referral"
        verbose_name_plural = "On-schedule: DM Referral"



from django.contrib import admin
from django.template.loader import render_to_string

from ..admin_site import meta_reports_admin
from ..models import Endpoints
from .modeladmin_mixins import EndpointsModelAdminMixin


@admin.register(Endpoints, site=meta_reports_admin)
class EndpointsAdmin(EndpointsModelAdminMixin, admin.ModelAdmin):
    queryset_filter = dict(offstudy_date__isnull=True)

    def rendered_change_list_note(self):
        return render_to_string("meta_reports/endpoints_change_list_note.html")



from datetime import datetime
from zoneinfo import ZoneInfo

from edc_consent.consent_definition import ConsentDefinition
from edc_consent.consent_definition_extension import ConsentDefinitionExtension
from edc_consent.site_consents import site_consents
from edc_constants.constants import FEMALE, MALE
from edc_protocol.research_protocol_config import ResearchProtocolConfig

consent_v1 = ConsentDefinition(
    "meta_consent.subjectconsentv1",
    version="1",
    start=ResearchProtocolConfig().study_open_datetime,
    end=ResearchProtocolConfig().study_close_datetime,
    age_min=18,
    age_is_adult=18,
    age_max=110,
    gender=[MALE, FEMALE],
    screening_model=[
        "meta_screening.subjectscreening",
        "meta_screening.screeningpartone",
        "meta_screening.screeningparttwo",
        "meta_screening.screeningpartthree",
    ],
    timepoints=list(range(1, 14 + 1)),
)

consent_v1_ext = ConsentDefinitionExtension(
    "meta_consent.subjectconsentv1ext",
    version="1.1",
    start=datetime(2024, 12, 16, tzinfo=ZoneInfo("UTC")),
    extends=consent_v1,
    timepoints=[15, 16, 17, 18],
)

site_consents.register(consent_v1, extended_by=consent_v1_ext)



# Generated by Django 5.0.8 on 2024-08-23 14:26

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0035_historicalmissingogttnote_missingogttnote"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalmissingogttnote",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Did the participant fast?",
            ),
        ),
        migrations.AddField(
            model_name="historicalmissingogttnote",
            name="fasting_duration_delta",
            field=models.DurationField(
                blank=True,
                help_text="system calculated to microseconds. (hours=microseconds/3.6e+9)",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalmissingogttnote",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AddField(
            model_name="missingogttnote",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Did the participant fast?",
            ),
        ),
        migrations.AddField(
            model_name="missingogttnote",
            name="fasting_duration_delta",
            field=models.DurationField(
                blank=True,
                help_text="system calculated to microseconds. (hours=microseconds/3.6e+9)",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="missingogttnote",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
    ]
